hermes_subagent_dispatch_available

Function hermes_subagent_dispatch_available 

pub fn hermes_subagent_dispatch_available() -> bool
Dynamically probe whether Hermes has the delegation toolset enabled.

Runs hermes tools list and checks for both enabled and delegation in the output.