pub enum GateError {
Io(Error),
Json(Error),
NoOpenGate {
phase: u32,
stage: Stage,
},
AlreadyResponded {
phase: u32,
stage: Stage,
},
}Expand description
Errors produced by the gate protocol.
Variants
Io(Error)
Filesystem operation failed.
Json(Error)
JSON parse or serialization failed.
NoOpenGate
Responding to a gate that was never fired (or already resolved).
AlreadyResponded
Responding to a gate that already has a response on disk.