pub struct BranchInfo {
pub name: String,
pub ahead: usize,
pub behind: usize,
pub last_commit: String,
}Expand description
Summary of a feature branch for the devflow list command.
Fields
name: StringBranch name (e.g. “feature/phase-05”).
ahead: usizeNumber of commits this branch has that develop doesn’t.
behind: usizeNumber of commits develop has that this branch doesn’t.
last_commit: StringISO-8601 date of the last commit on this branch.