pub fn attempt_timeline(project_root: &Path, phase: u32) -> AttemptTimelineExpand description
Correlate schema-v1 events, retained capture generations, and review artifacts without creating a second history store.
pub fn attempt_timeline(project_root: &Path, phase: u32) -> AttemptTimelineCorrelate schema-v1 events, retained capture generations, and review artifacts without creating a second history store.