pub fn list(project_root: &Path) -> Result<Vec<WorktreeInfo>, WorktreeError>Expand description
List all worktrees for the repository by parsing --porcelain output.
pub fn list(project_root: &Path) -> Result<Vec<WorktreeInfo>, WorktreeError>List all worktrees for the repository by parsing --porcelain output.