pub fn prune(project_root: &Path) -> Result<(), WorktreeError>Expand description
Prune stale worktree administrative entries via git worktree prune.
pub fn prune(project_root: &Path) -> Result<(), WorktreeError>Prune stale worktree administrative entries via git worktree prune.