pub fn hermes_subagent_dispatch_available() -> bool
Dynamically probe whether Hermes has the delegation toolset enabled.
delegation
Runs hermes tools list and checks for both enabled and delegation in the output.
hermes tools list
enabled